@@ -37,8 +37,6 @@ struct _GgvPostscriptViewPrivate {
 	gdouble prev_x, prev_y;
 	gchar *tmp_name;
 
-	GConfClient	*conf_client;
-
 	BonoboPropertyBag     *property_bag;
 	BonoboPropertyControl *property_control;
 
@@ -140,6 +138,8 @@ view_button_press_cb(GtkWidget *widget, GdkEventButton *event, gpointer data)
 			
 		gdk_window_get_pointer(widget->window, &wx, &wy, NULL);
 			
+		gtk_gs_start_scroll(ps_view->priv->gs);
+
 		ps_view->priv->pan = TRUE;
 		if(pan_cursor == NULL)
 			pan_cursor = gdk_cursor_new(GDK_FLEUR);
@@ -168,6 +168,7 @@ view_button_release_cb(GtkWidget *widget, GdkEventButton *event, gpointer data)
 		ps_view->priv->pan = FALSE;
 		gdk_pointer_ungrab(GDK_CURRENT_TIME);
 		gtk_grab_remove(widget);
+		gtk_gs_end_scroll(ps_view->priv->gs);
 	}
 }
 
@@ -445,6 +446,7 @@ ggv_postscript_view_create_ui(GgvPostscriptView *ps_view)
 		BONOBO_UI_VERB_END
 	};
 	BonoboUINode *new_media_menus;
+	BonoboUINode *ui_root;
 	GgvPostscriptViewClass *klass = GGV_POSTSCRIPT_VIEW_CLASS(GTK_OBJECT(ps_view)->klass);
 	gint i;
 
@@ -452,8 +454,15 @@ ggv_postscript_view_create_ui(GgvPostscriptView *ps_view)
 	g_return_if_fail(GGV_IS_POSTSCRIPT_VIEW(ps_view));
 
 	/* Set up the UI from an XML file. */
-	bonobo_ui_util_set_ui(ps_view->priv->uic, DATADIR,
-						  "ggv-postscript-view-ui.xml", "GgvPostscriptView");
+#if 1
+	ui_root = bonobo_ui_util_new_ui(ps_view->priv->uic, DATADIR,
+									"ggv-postscript-view-ui.xml", "GgvPostscriptView");
+	bonobo_ui_util_translate_ui(ui_root);
+	bonobo_ui_component_set_tree(ps_view->priv->uic, "/", ui_root, NULL);
+#else
+	bonobo_ui_util_set_ui(ps_view->priv->uic, "ggv-postscript-view-ui.xml", 
+						  DATADIR, "GgvPostscriptView");
+#endif
 
 	new_media_menus = bonobo_ui_node_copy(klass->priv->media_menus, TRUE);
 	if(new_media_menus)
@@ -843,16 +852,15 @@ ggv_postscript_view_set_zoom(GgvPostscriptView *ps_view,
 	gtk_gs_set_zoom(GTK_GS(ps_view->priv->gs), zoomx);
 }
 
-void
+gfloat
 ggv_postscript_view_zoom_to_fit(GgvPostscriptView *ps_view,
-								gboolean keep_aspect_ratio)
+								gboolean fit_width)
 {
 	g_return_if_fail(ps_view != NULL);
 	g_return_if_fail(GGV_IS_POSTSCRIPT_VIEW(ps_view));
 
 	/* we don't know how not to keep the aspect ratio */
-
-	gtk_gs_zoom_to_fit(GTK_GS(ps_view->priv->gs));
+	return  gtk_gs_zoom_to_fit(GTK_GS(ps_view->priv->gs), fit_width);
 }
 
 void
@@ -899,8 +907,6 @@ ggv_postscript_view_destroy(GtkObject *object)
 
 	ps_view = GGV_POSTSCRIPT_VIEW(object);
 
-	gtk_object_unref(GTK_OBJECT(ps_view->priv->conf_client));
-
 	if(ps_view->priv->property_bag)
 		bonobo_object_unref(BONOBO_OBJECT(ps_view->priv->property_bag));
 	ps_view->priv->property_bag = NULL;
@@ -1069,8 +1075,6 @@ ggv_postscript_view_construct(GgvPostscriptView *ps_view,
 	if(!gconf_is_initialized())
 		gconf_init(0, NULL, NULL);
 	
-	ps_view->priv->conf_client = gconf_client_get_default();
-
 	ps_view->priv->gs = GTK_WIDGET(gs);
 	gtk_widget_set_events(GTK_WIDGET(gs), 
 						  GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
