@@ -1005,7 +1005,14 @@ void zoom_to_fit_callback(GtkWidget *widget, gpointer data)
 {
         ggv_window *ggv = (ggv_window *)data;
 
-        gtk_gs_zoom_to_fit(GTK_GS(ggv->gs));
+        zoom_to_fit(ggv, FALSE);
+}
+
+void zoom_to_fit_width_callback(GtkWidget *widget, gpointer data)
+{
+        ggv_window *ggv = (ggv_window *)data;
+
+        zoom_to_fit(ggv, TRUE);
 }
 
 void zoom_callback(GtkWidget *widget, gpointer data)
